# RachelCore

Rachel assistant core.

Here is main core that Rachel works with. Rachel is no Rachel without this core.

You don't need to install RachelCore in your system. When you install Rachel, it will be installed.

RachelCore installs via [PyPi](https://pypi.org/project/RachelCore).

[Rachel main repository](https://github.com/BlackIQ/Rachel)

Amirhossein Mohammadi. 2019 - 2021 &copy;
Licensed under MIT license.